@@ -12,12 +12,12 @@
 #
 ##############################################################################
 """
-$Id: tests.py 90851 2008-09-04 23:42:08Z mgedmin $
+$Id: tests.py 115969 2010-08-27 18:07:11Z mgedmin $
 """
 import unittest
+import doctest
 
 import transaction
-from zope.testing import doctest
 from zope.app.testing import setup
 from zope.component import provideUtility
 from zope.interface.verify import verifyObject
